#version 150
uniform sampler2D textureID;
uniform float time;

in vec2 textureCoord;
out vec4 outColor;


// chromatic distort
uniform float chromaticStrength;
uniform vec2 rdir,gdir,bdir;
// scanline
uniform float scanlineStrength;
// tearing strength
uniform float tearingStrength, tearingPosition;
// ghosting
uniform float ghostingStrength;
uniform vec2 ghostingOffset;

void main(void) {
	outColor = vec4(0.0, 0.0, 0.0, 0.0);
	vec2 texPos = textureCoord.st;

	// Tearing
    texPos.s +=  min(sign(texPos.t + tearingPosition - 1.0), 0.0) * tearingStrength;

	// Chromatic distort
	vec2 pR = texPos.st + chromaticStrength/128.0 * rdir;
	vec2 pG = texPos.st + chromaticStrength/128.0 * gdir;
	vec2 pB = texPos.st + chromaticStrength/128.0 * bdir;
	outColor += vec4(texture(textureID, pR).r, texture(textureID, pG).g, texture(textureID, pB).b, 1.0);

    // Ghosting
    outColor += (texture(textureID, textureCoord.st) * (1.0 - ghostingStrength)) + (texture(textureID, textureCoord.st + ghostingOffset) * ghostingStrength);

	// Scanline
	float gap = 5.0;
	float value = abs(mod((texPos.t * 800.0 + mod(time, 1.0) * gap), gap) - gap / 2.0);
	value = min(value * value / 12.0 + 1.0 - scanlineStrength, 1.0);
	outColor += vec4(texture(textureID, texPos.st).rgb * value, 1.0);

	outColor /= 3.0;
}